thread_data_text

Function thread_data_text 

pub fn thread_data_text(
    f: &File,
    thread: usize,
    n_threads: usize,
) -> Result<(Mmap, usize), Error>
Get thread-specific data.

This function will return a memory map of the corpus data. The initial starting position for the given thread is also returned. This starting Position will always be the beginning of a sentence.