pub fn thread_data_conllx(
f: &File,
thread: usize,
n_threads: usize,
) -> Result<(Mmap, usize), Error>Expand description
Get thread-specific data for a CONLLX-Corpus.
This function will return a memory map of the corpus data. The initial starting position for the given thread is also returned. This starting Position will always be the beginning of a sentence.